#ifndef MAPITEM_H
#define MAPITEM_H

#include <QPointF>

#include "xmlobj.h"

class LinkableMapObj;

/*! /brief MapItem is used to store information of MapObj and inherited
   classes.
 
	This is done even while no QGraphicsView is availabe. This is useful
	if e.g. on a small device like a cellphone te full map is not used,
	but just a treeview instead.
*/

class MapItem:public XMLObj
{
public:
	enum PositionMode {Unused,Absolute,Relative};
protected:
	QPointF pos;
	PositionMode posMode;

public:
	MapItem();
	void init();

	/*! Used to save relative position while map is not in QGraphicsView */
	virtual void setRelPos(const QPointF&);	

	/*! Used to save absolute position while map is not in QGraphicsView */
	virtual void setAbsPos(const QPointF&);	

	/*! Tell object to use e.g. absolute positioning for mapcenter. 
	    Defaulst is MapItem::Unused */
	void setPositionMode (PositionMode mode);

protected:
	LinkableMapObj *lmo;
public:
	/*! Returns pointer to related LinkableMapObj in QGraphicsView */
	virtual LinkableMapObj* getLMO();

	/*! Set pointer to related LinkableMapObj in QGraphicsView */
	virtual void setLMO (LinkableMapObj*);

	/*! Initialize LinkableMapObj with data in MapItem */
	virtual void initLMO();

};


#endif
